@@ -1,11 +1,14 @@
-#!/usr/bin/python3.10
+#!/usr/bin/python3.11
 
 import sys
+
+from osgeo.gdal import UseExceptions, deprecation_warn
+
 # import osgeo_utils.gdal_polygonize as a convenience to use as a script
 from osgeo_utils.gdal_polygonize import *  # noqa
 from osgeo_utils.gdal_polygonize import main
-from osgeo.gdal import deprecation_warn
 
+UseExceptions()
 
-deprecation_warn('gdal_polygonize')
+deprecation_warn("gdal_polygonize")
 sys.exit(main(sys.argv))
